@@ -6,12 +6,13 @@ use warnings;
 use Config '%Config';
 
 use Fcntl;    # for sysopen
+use File::Basename qw(basename);
 use File::Spec::Functions qw(catfile catdir splitdir);
 
 use vars qw($VERSION @Pagers $Bindir $Pod2man
   $Temp_Files_Created $Temp_File_Lifetime
 );
-$VERSION = '3.15_09';
+$VERSION = '3.15_10';
 
 #..........................................................................
 
@@ -49,13 +50,13 @@ sub FALSE () {return}
 sub BE_LENIENT () {1}
 
 BEGIN {
- *IS_VMS     = $^O eq 'VMS'     ? \&TRUE : \&FALSE unless defined &IS_VMS;
- *IS_MSWin32 = $^O eq 'MSWin32' ? \&TRUE : \&FALSE unless defined &IS_MSWin32;
- *IS_Dos     = $^O eq 'dos'     ? \&TRUE : \&FALSE unless defined &IS_Dos;
- *IS_OS2     = $^O eq 'os2'     ? \&TRUE : \&FALSE unless defined &IS_OS2;
- *IS_Cygwin  = $^O eq 'cygwin'  ? \&TRUE : \&FALSE unless defined &IS_Cygwin;
- *IS_Linux   = $^O eq 'linux'   ? \&TRUE : \&FALSE unless defined &IS_Linux;
- *IS_HPUX    = $^O =~ m/hpux/   ? \&TRUE : \&FALSE unless defined &IS_HPUX;
+ *is_vms     = $^O eq 'VMS'     ? \&TRUE : \&FALSE unless defined &is_vms;
+ *is_mswin32 = $^O eq 'MSWin32' ? \&TRUE : \&FALSE unless defined &is_mswin32;
+ *is_dos     = $^O eq 'dos'     ? \&TRUE : \&FALSE unless defined &is_dos;
+ *is_os2     = $^O eq 'os2'     ? \&TRUE : \&FALSE unless defined &is_os2;
+ *is_cygwin  = $^O eq 'cygwin'  ? \&TRUE : \&FALSE unless defined &is_cygwin;
+ *is_linux   = $^O eq 'linux'   ? \&TRUE : \&FALSE unless defined &is_linux;
+ *is_hpux    = $^O =~ m/hpux/   ? \&TRUE : \&FALSE unless defined &is_hpux;
 }
 
 $Temp_File_Lifetime ||= 60 * 60 * 24 * 5;
@@ -66,7 +67,7 @@ $Temp_File_Lifetime ||= 60 * 60 * 24 * 5;
 
 #..........................................................................
 { my $pager = $Config{'pager'};
-  push @Pagers, $pager if -x (split /\s+/, $pager)[0] or IS_VMS;
+  push @Pagers, $pager if -x (split /\s+/, $pager)[0] or __PACKAGE__->is_vms;
 }
 $Bindir  = $Config{'scriptdirexp'};
 $Pod2man = "pod2man" . ( $Config{'versiononly'} ? $Config{'version'} : '' );
@@ -263,11 +264,11 @@ Options:
     -V   Report version
     -r   Recursive search (slow)
     -i   Ignore case
-    -t   Display pod using pod2text instead of pod2man and nroff
+    -t   Display pod using pod2text instead of Pod::Man and groff
              (-t is the default on win32 unless -n is specified)
     -u   Display unformatted pod text
     -m   Display module's file in its entirety
-    -n   Specify replacement for nroff
+    -n   Specify replacement for groff
     -l   Display the module's file name
     -F   Arguments are file names, not modules
     -D   Verbosely describe what's going on
@@ -291,7 +292,7 @@ PageName|ModuleName|ProgramName|URL...
 
 BuiltinFunction
          is the name of a perl function.  Will extract documentation from
-         `perlfunc'.
+         `perlfunc' or `perlop'.
 
 FAQRegex
          is a regex. Will search perlfaq[1-9] for and extract any
@@ -308,26 +309,83 @@ EOF
 #..........................................................................
 
 sub program_name {
-  my $me = $0;  # Editing $0 is unportable
+  my( $self ) = @_;
 
-  $me =~ s,.*[/\\],,; # get basename
+  if( my $link = readlink( $0 ) ) {
+    $self->debug( "The value in $0 is a symbolic link to $link\n" );
+    }
 
-  return $me;
+  my $basename = basename( $0 );
+
+  # possible name forms
+  #   perldoc
+  #   perldoc-v5.14
+  #   perldoc-5.14
+  #   perldoc-5.14.2
+  #   perlvar         # an alias mentioned in Camel 3
+  {
+  my( $untainted ) = $basename =~ m/(
+    \A
+    perl
+      (?:
+      doc | func | faq | help | op | toc | var # Camel 3
+      )
+    (?: -? v? \d+ \. \d+ (?:\. \d+)? ) # possible version
+    (?: \. (?: bat | exe | com ) )?    # possible extension
+    \z
+    )
+    /x;
+
+  return $untainted if $untainted;
+  }
+
+  $self->warn(<<"HERE");
+You called the perldoc command with a name that I didn't recognize.
+This might mean that someone is tricking you into running a
+program you don't intend to use, but it also might mean that you
+created your own link to perldoc.
+
+I'll allow this if the filename looks only has [a-zA-Z0-9._-].
+HERE
+
+  {
+  my( $untainted ) = $basename =~ m/(
+    \A [a-zA-Z0-9._-]+ \z
+    )/x;
+
+  return $untainted if $untainted;
+  }
+
+  $self->die(<<"HERE");
+I think that your name for perldoc is potentially unsafe, so I'm
+going to disallow it. I'd rather you be safe than sorry. If you
+intended to use the name I'm disallowing, please tell the maintainers
+about it. Write to:
+
+    Pod-Perldoc\@rt.cpan.org
+
+HERE
 }
 
 #..........................................................................
 
 sub usage_brief {
   my $self = shift;
-  my $me = $self->program_name;
+  my $program_name = $self->program_name;
 
   $self->die( <<"EOUSAGE" );
-Usage: $me [-h] [-V] [-r] [-i] [-D] [-t] [-u] [-m] [-n nroffer_program] [-l] [-T] [-d output_filename] [-o output_format] [-M FormatterModuleNameToUse] [-w formatter_option:option_value] [-L translation_code] [-F] [-X] PageName|ModuleName|ProgramName
-       $me -f PerlFunc
-       $me -q FAQKeywords
-       $me -v PerlVar
+Usage: $program_name [-hVriDtumFXlT] [-n nroffer_program]
+    [-d output_filename] [-o output_format] [-M FormatterModule]
+    [-w formatter_option:option_value] [-L translation_code]
+    PageName|ModuleName|ProgramName
 
-The -h option prints more help.  Also try "$me perldoc" to get
+Examples:
+
+    $program_name -f PerlFunc
+    $program_name -q FAQKeywords
+    $program_name -v PerlVar
+
+The -h option prints more help.  Also try "$program_name perldoc" to get
 acquainted with the system.                        [Perldoc v$VERSION]
 EOUSAGE
 
@@ -397,7 +455,7 @@ sub init_formatter_class_list {
 
   $self->opt_M_with('Pod::Perldoc::ToPod');   # the always-there fallthru
   $self->opt_o_with('text');
-  $self->opt_o_with('man') unless IS_MSWin32 || IS_Dos
+  $self->opt_o_with('man') unless $self->is_mswin32 || $self->is_dos
        || !($ENV{TERM} && (
               ($ENV{TERM} || '') !~ /dumb|emacs|none|unknown/i
            ));
@@ -443,7 +501,7 @@ sub process {
 
     my @pages;
     $self->{'pages'} = \@pages;
-    if(    $self->opt_f) { @pages = ("perlfunc")               }
+    if(    $self->opt_f) { @pages = qw(perlfunc perlop)        }
     elsif( $self->opt_q) { @pages = ("perlfaq1" .. "perlfaq9") }
     elsif( $self->opt_v) { @pages = ("perlvar")                }
     else                 { @pages = @{$self->{'args'}};
@@ -460,7 +518,7 @@ sub process {
       # for when we're apparently in a module or extension directory
 
     my @found = $self->grand_search_init(\@pages);
-    exit (IS_VMS ? 98962 : 1) unless @found;
+    exit ($self->is_vms ? 98962 : 1) unless @found;
 
     if ($self->opt_l) {
         DEBUG and print "We're in -l mode, so byebye after this:\n";
@@ -507,7 +565,7 @@ sub find_good_formatter_class {
        "Interesting, the formatter class $c is already loaded!\n";
 
     } elsif(
-      (IS_VMS or IS_MSWin32 or IS_Dos or IS_OS2)
+      ( $self->is_os2 or $self->is_mswin32 or $self->is_dos or $self->is_os2)
        # the always case-insensitive filesystems
       and $class_seen{lc("~$c")}++
     ) {
@@ -680,7 +738,7 @@ sub options_processing {
 
     $self->options_sanity;
 
-    $self->opt_n("nroff") unless $self->opt_n;
+    $self->opt_n("groff") unless $self->opt_n;
     $self->add_formatter_option( '__nroffer' => $self->opt_n );
 
     # Get language from PERLDOC_POD2 environment variable
@@ -771,7 +829,7 @@ sub grand_search_init {
 
         if ($self->opt_F) {
             next unless -r;
-            push @found, $_ if $self->opt_m or $self->containspod($_);
+            push @found, $_ if $self->opt_l or $self->opt_m or $self->containspod($_);
             next;
         }
 
@@ -784,7 +842,7 @@ sub grand_search_init {
         # for executables, like h2xs or perldoc itself.
         push @searchdirs, ($self->{'bindir'}, @INC);
         unless ($self->opt_m) {
-            if (IS_VMS) {
+            if ($self->is_vms) {
                 my($i,$trn);
                 for ($i = 0; $trn = $ENV{'DCL$PATH;'.$i}; $i++) {
                     push(@searchdirs,$trn);
@@ -855,7 +913,7 @@ sub maybe_generate_dynamic_pod {
         push @{ $self->{'temp_file_list'} }, $buffer;
          # I.e., it MIGHT be deleted at the end.
 
-    my $in_list = $self->opt_f || $self->opt_v;
+        my $in_list = !$self->not_dynamic && $self->opt_f || $self->opt_v;
 
         print $buffd "=over 8\n\n" if $in_list;
         print $buffd @dynamic_pod  or $self->die( "Can't print $buffer: $!" );
@@ -879,6 +937,14 @@ sub maybe_generate_dynamic_pod {
 
 #..........................................................................
 
+sub not_dynamic {
+  my ($self,$value) = @_;
+  $self->{__not_dynamic} = $value if @_ == 2;
+  return $self->{__not_dynamic};
+}
+
+#..........................................................................
+
 sub add_formatter_option { # $self->add_formatter_option('key' => 'value');
   my $self = shift;
   push @{ $self->{'formatter_switches'} }, [ @_ ] if @_;
@@ -1003,6 +1069,59 @@ sub search_perlvar {
 
 #..........................................................................
 
+sub search_perlop {
+  my ($self,$found_things,$pod) = @_;
+
+  $self->not_dynamic( 1 );
+
+  my $perlop = shift @$found_things;
+  open( PERLOP, '<', $perlop ) or $self->die( "Can't open $perlop: $!" );
+
+  my $paragraph = "";
+  my $has_text_seen = 0;
+  my $thing = $self->opt_f;
+  my $list = 0;
+
+  while( my $line = <PERLOP> ){
+    if( $paragraph and $line =~ m!^=(?:head|item)! and $paragraph =~ m!X<+\s*\Q$thing\E\s*>+! ){
+      if( $list ){
+        $paragraph =~ s!=back.*?\z!!s;
+      }
+
+      if( $paragraph =~ m!^=item! ){
+        $paragraph = "=over 8\n\n" . $paragraph . "=back\n";
+      }
+
+      push @$pod, $paragraph;
+      $paragraph = "";
+      $has_text_seen = 0;
+      $list = 0;
+    }
+
+    if( $line =~ m!^=over! ){
+      $list++;
+    }
+    elsif( $line =~ m!^=back! ){
+      $list--;
+    }
+
+    if( $line =~ m!^=(?:head|item)! and $has_text_seen ){
+      $paragraph = "";
+    }
+    elsif( $line !~ m!^=(?:head|item)! and $line !~ m!^\s*$! and $line !~ m!^\s*X<! ){
+      $has_text_seen = 1;
+    }
+
+    $paragraph .= $line;
+    }
+
+  close PERLOP;
+
+  return;
+}
+
+#..........................................................................
+
 sub search_perlfunc {
     my($self, $found_things, $pod) = @_;
 
@@ -1036,13 +1155,31 @@ sub search_perlfunc {
     # Look for our function
     my $found = 0;
     my $inlist = 0;
+
+    my @perlops = qw(m q qq qr qx qw s tr y);
+
+    my @related;
+    my $related_re;
     while (<PFUNC>) {  # "The Mothership Connection is here!"
+        last if( grep{ $self->opt_f eq $_ }@perlops );
         if ( m/^=item\s+$search_re\b/ )  {
             $found = 1;
         }
+        elsif (@related > 1 and /^=item/) {
+            $related_re ||= join "|", @related;
+            if (m/^=item\s+(?:$related_re)\b/) {
+                $found = 1;
+            }
+            else {
+                last;
+            }
+        }
         elsif (/^=item/) {
             last if $found > 1 and not $inlist;
         }
+        elsif ($found and /^X<[^>]+>/) {
+            push @related, m/X<([^>]+)>/g;
+        }
         next unless $found;
         if (/^=over/) {
             ++$inlist;
@@ -1054,6 +1191,11 @@ sub search_perlfunc {
         push @$pod, $_;
         ++$found if /^\w/;        # found descriptive text
     }
+
+    if( !@$pod ){
+        $self->search_perlop( $found_things, $pod );
+    }
+
     if (!@$pod) {
         $self->die( sprintf
           "No documentation for perl function `%s' found\n",
@@ -1233,129 +1375,25 @@ sub unlink_if_temp_file {
 
 #..........................................................................
 
-sub MSWin_temp_cleanup {
-
-  # Nothing particularly MSWin-specific in here, but I don't know if any
-  # other OS needs its temp dir policed like MSWin does!
-
-  my $self = shift;
-
-  my $tempdir = $ENV{'TEMP'};
-  return unless defined $tempdir and length $tempdir
-   and -e $tempdir and -d _ and -w _;
-
-  $self->aside(
-   "Considering whether any old files of mine in $tempdir need unlinking.\n"
-  );
-
-  opendir(TMPDIR, $tempdir) || return;
-  my @to_unlink;
-
-  my $limit = time() - $Temp_File_Lifetime;
-
-  DEBUG > 5 and printf "Looking for things pre-dating %s (%x)\n",
-   ($limit) x 2;
-
-  my $filespec;
-
-  while(defined($filespec = readdir(TMPDIR))) {
-    if(
-     $filespec =~ m{^perldoc_[a-zA-Z0-9]+_T([a-fA-F0-9]{7,})_[a-fA-F0-9]{3,}}s
-    ) {
-      if( hex($1) < $limit ) {
-        push @to_unlink, "$tempdir/$filespec";
-        $self->aside( "Will unlink my old temp file $to_unlink[-1]\n" );
-      } else {
-        DEBUG > 5 and
-         printf "  $tempdir/$filespec is too recent (after %x)\n", $limit;
-      }
-    } else {
-      DEBUG > 5 and
-       print "  $tempdir/$filespec doesn't look like a perldoc temp file.\n";
-    }
-  }
-  closedir(TMPDIR);
-  $self->aside(sprintf "Unlinked %s items of mine in %s\n",
-    scalar(unlink(@to_unlink)),
-    $tempdir
-  );
-  return;
-}
-
-#  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .
-
-sub MSWin_perldoc_tempfile {
-  my($self, $suffix, $infix) = @_;
-
-  my $tempdir = $ENV{'TEMP'};
-  return unless defined $tempdir and length $tempdir
-   and -e $tempdir and -d _ and -w _;
-
-  my $spec;
-
-  do {
-    $spec = sprintf "%s\\perldoc_%s_T%x_%x%02x.%s", # used also in MSWin_temp_cleanup
-      # Yes, we embed the create-time in the filename!
-      $tempdir,
-      $infix || 'x',
-      time(),
-      $$,
-      defined( &Win32::GetTickCount )
-        ? (Win32::GetTickCount() & 0xff)
-        : int(rand 256)
-       # Under MSWin, $$ values get reused quickly!  So if we ran
-       # perldoc foo and then perldoc bar before there was time for
-       # time() to increment time."_$$" would likely be the same
-       # for each process!  So we tack on the tick count's lower
-       # bits (or, in a pinch, rand)
-      ,
-      $suffix || 'txt';
-    ;
-  } while( -e $spec );
-
-  my $counter = 0;
-
-  while($counter < 50) {
-    my $fh;
-    # If we are running before perl5.6.0, we can't autovivify
-    if ($] < 5.006) {
-      require Symbol;
-      $fh = Symbol::gensym();
-    }
-    DEBUG > 3 and print "About to try making temp file $spec\n";
-    return($fh, $spec) if open($fh, ">", $spec);    # XXX 5.6ism
-    $self->aside("Can't create temp file $spec: $!\n");
-  }
-
-  $self->aside("Giving up on making a temp file!\n");
-  $self->die( "Can't make a tempfile!?" );
-}
-
-#..........................................................................
-
 
 sub after_rendering {
   my $self = $_[0];
-  $self->after_rendering_VMS     if IS_VMS;
-  $self->after_rendering_MSWin32 if IS_MSWin32;
-  $self->after_rendering_Dos     if IS_Dos;
-  $self->after_rendering_OS2     if IS_OS2;
+  $self->after_rendering_VMS     if $self->is_vms;
+  $self->after_rendering_MSWin32 if $self->is_mswin32;
+  $self->after_rendering_Dos     if $self->is_dos;
+  $self->after_rendering_OS2     if $self->is_os2;
   return;
 }
 
 sub after_rendering_VMS      { return }
 sub after_rendering_Dos      { return }
 sub after_rendering_OS2      { return }
-
-sub after_rendering_MSWin32  {
-  shift->MSWin_temp_cleanup() if $Temp_Files_Created;
-}
+sub after_rendering_MSWin32  { return }
 
 #..........................................................................
 #   :   :   :   :   :   :   :   :   :
 #..........................................................................
 
-
 sub minus_f_nocase {   # i.e., do like -f, but without regard to case
 
      my($self, $dir, $file) = @_;
@@ -1363,8 +1401,8 @@ sub minus_f_nocase {   # i.e., do like -f, but without regard to case
      return $path if -f $path and -r _;
 
      if(!$self->opt_i
-        or IS_VMS or IS_MSWin32
-        or IS_Dos or IS_OS2
+        or $self->is_vms or $self->is_mswin32
+        or $self->Is_dos or $self->is_os2
      ) {
         # On a case-forgiving file system, or if case is important,
     #  that is it, all we can do.
@@ -1391,11 +1429,11 @@ sub minus_f_nocase {   # i.e., do like -f, but without regard to case
         $self->aside( "Found as $tmp_path but directory\n" );
         }
     }
-    elsif (-f _ && -r _) {
+    elsif (-f _ && -r _ && lc($try) eq lc($path)) {
         return $try;
     }
     elsif (-f _) {
-        $self->warn( "Ignored $try: unreadable\n" );
+        $self->warn( "Ignored $try: unreadable or file/dir mismatch\n" );
     }
     elsif (-d catdir(@p)) {  # at least we see the containing directory!
         my $found = 0;
@@ -1429,29 +1467,30 @@ sub pagers_guessing {
     push @pagers, $self->pagers;
     $self->{'pagers'} = \@pagers;
 
-    if (IS_MSWin32) {
+    if ($self->is_mswin32) {
         push @pagers, qw( more< less notepad );
         unshift @pagers, $ENV{PAGER}  if $ENV{PAGER};
     }
-    elsif (IS_VMS) {
+    elsif ($self->is_vms) {
         push @pagers, qw( most more less type/page );
     }
-    elsif (IS_Dos) {
+    elsif ($self->is_dos) {
         push @pagers, qw( less.exe more.com< );
         unshift @pagers, $ENV{PAGER}  if $ENV{PAGER};
     }
     else {
-        if (IS_OS2) {
+        if ($self->is_os2) {
           unshift @pagers, 'less', 'cmd /c more <';
         }
         push @pagers, qw( more less pg view cat );
-        unshift @pagers, $ENV{PAGER}  if $ENV{PAGER};
+        unshift @pagers, "$ENV{PAGER}<"  if $ENV{PAGER};
     }
 
-    if (IS_Cygwin) {
+    if ($self->is_cygwin) {
         if (($pagers[0] eq 'less') || ($pagers[0] eq '/usr/bin/less')) {
             unshift @pagers, '/usr/bin/less -isrR';
-        }
+            unshift @pagers, $ENV{PAGER}  if $ENV{PAGER};
+       }
     }
 
     unshift @pagers, $ENV{PERLDOC_PAGER} if $ENV{PERLDOC_PAGER};
@@ -1476,55 +1515,16 @@ sub page_module_file {
     # occasionally hazy distinction between OS-local extension
     # associations, and browser-specific MIME mappings.
 
-    if ($self->{'output_to_stdout'}) {
-        $self->aside("Sending unpaged output to STDOUT.\n");
-    local $_;
-    my $any_error = 0;
-        foreach my $output (@found) {
-        unless( open(TMP, "<", $output) ) {    # XXX 5.6ism
-          $self->warn("Can't open $output: $!");
-          $any_error = 1;
-          next;
-        }
-        while (<TMP>) {
-            print or $self->die( "Can't print to stdout: $!" );
-        }
-        close TMP  or $self->die( "Can't close while $output: $!" );
-        $self->unlink_if_temp_file($output);
-    }
-    return $any_error; # successful
+    if(@found > 1) {
+        $self->warn(
+            "Perldoc is only really meant for reading one document at a time.\n" .
+            "So these files are being ignored: " .
+            join(' ', @found[1 .. $#found] ) .
+            "\n" )
     }
 
-    foreach my $pager ( $self->pagers ) {
-        $self->aside("About to try calling $pager @found\n");
-        if (system($pager, @found) == 0) {
-            $self->aside("Yay, it worked.\n");
-            return 0;
-        }
-        $self->aside("That didn't work.\n");
+    return $self->page($found[0], $self->{'output_to_stdout'}, $self->pagers);
 
-        # Odd -- when it fails, under Win32, this seems to neither
-        #  return with a fail nor return with a success!!
-        #  That's discouraging!
-    }
-
-    $self->aside(
-      sprintf "Can't manage to find a way to page [%s] via pagers [%s]\n",
-      join(' ', @found),
-      join(' ', $self->pagers),
-    );
-
-    if (IS_VMS) {
-        DEBUG > 1 and print "Bailing out in a VMSish way.\n";
-        eval q{
-            use vmsish qw(status exit);
-            exit $?;
-            1;
-        } or $self->die;
-    }
-
-    return 1;
-      # i.e., an UNSUCCESSFUL return value!
 }
 
 #..........................................................................
@@ -1548,23 +1548,35 @@ sub check_file {
       return "";
     }
 
-    if ($self->opt_m) {
-    return $self->minus_f_nocase($dir,$file);
-    }
-
-    else {
     my $path = $self->minus_f_nocase($dir,$file);
-        if( length $path and $self->containspod($path) ) {
-            DEBUG > 3 and print
-              "  The file $path indeed looks promising!\n";
-            return $path;
-        }
+    if( length $path and ($self->opt_m ? $self->isprintable($path)
+                                      : $self->containspod($path)) ) {
+        DEBUG > 3 and print
+            "  The file $path indeed looks promising!\n";
+        return $path;
     }
     DEBUG > 3 and print "  No good: $file in $dir\n";
 
     return "";
 }
 
+sub isprintable {
+	my($self, $file, $readit) = @_;
+	my $size= 1024;
+	my $maxunprintfrac= 0.2;   # tolerate some unprintables for UTF-8 comments etc.
+
+	return 1 if !$readit && $file =~ /\.(?:pl|pm|pod|cmd|com|bat)\z/i;
+
+	my $data;
+	local($_);
+	open(TEST,"<", $file)     or $self->die( "Can't open $file: $!" );
+	read TEST, $data, $size;
+	close TEST;
+	$size= length($data);
+	$data =~ tr/\x09-\x0D\x20-\x7E//d;
+	return length($data) <= $size*$maxunprintfrac;
+}
+
 #..........................................................................
 
 sub containspod {
@@ -1585,7 +1597,7 @@ sub containspod {
     #
     #     $ perldoc perl.pod
 
-    if ( IS_Cygwin  and  -x $file  and  -f "$file.exe" )
+    if ( $self->is_cygwin  and  -x $file  and  -f "$file.exe" )
     {
         $self->warn( "Cygwin $file.exe search skipped\n" ) if DEBUG or $self->opt_D;
         return 0;
@@ -1638,7 +1650,7 @@ sub new_output_file {
 
   my $fh;
   # If we are running before perl5.6.0, we can't autovivify
-  if ($] < 5.006) {
+  if ($^V < 5.006) {
     require Symbol;
     $fh = Symbol::gensym();
   }
@@ -1688,12 +1700,6 @@ sub new_tempfile {    # $self->new_tempfile( [$suffix, [$infix] ] )
 
   ++$Temp_Files_Created;
 
-  if( IS_MSWin32 ) {
-    my @out = $self->MSWin_perldoc_tempfile(@_);
-    return @out if @out;
-    # otherwise fall thru to the normal stuff below...
-  }
-
   require File::Temp;
   return File::Temp::tempfile(UNLINK => 1);
 }
@@ -1704,32 +1710,32 @@ sub page {  # apply a pager to the output file
     my ($self, $output, $output_to_stdout, @pagers) = @_;
     if ($output_to_stdout) {
         $self->aside("Sending unpaged output to STDOUT.\n");
-    open(TMP, "<", $output)  or  $self->die( "Can't open $output: $!" ); # XXX 5.6ism
-    local $_;
-    while (<TMP>) {
-        print or $self->die( "Can't print to stdout: $!" );
-    }
-    close TMP  or $self->die( "Can't close while $output: $!" );
-    $self->unlink_if_temp_file($output);
+        open(TMP, "<", $output)  or  $self->die( "Can't open $output: $!" ); # XXX 5.6ism
+        local $_;
+        while (<TMP>) {
+            print or $self->die( "Can't print to stdout: $!" );
+        }
+        close TMP  or $self->die( "Can't close while $output: $!" );
+        $self->unlink_if_temp_file($output);
     } else {
         # On VMS, quoting prevents logical expansion, and temp files with no
         # extension get the wrong default extension (such as .LIS for TYPE)
 
-        $output = VMS::Filespec::rmsexpand($output, '.') if IS_VMS;
+        $output = VMS::Filespec::rmsexpand($output, '.') if $self->is_vms;
 
-        $output =~ s{/}{\\}g if IS_MSWin32 || IS_Dos;
-          # Altho "/" under MSWin is in theory good as a pathsep,
-          #  many many corners of the OS don't like it.  So we
-          #  have to force it to be "\" to make everyone happy.
+        $output =~ s{/}{\\}g if $self->is_mswin32 || $self->is_dos;
+        # Altho "/" under MSWin is in theory good as a pathsep,
+        #  many many corners of the OS don't like it.  So we
+        #  have to force it to be "\" to make everyone happy.
 
         foreach my $pager (@pagers) {
             $self->aside("About to try calling $pager $output\n");
-            if (IS_VMS) {
+            if ($self->is_vms) {
                 last if system("$pager $output") == 0;
             } else {
-            last if system("$pager \"$output\"") == 0;
+                last if system("$pager \"$output\"") == 0;
             }
-    }
+        }
     }
     return;
 }
@@ -1739,7 +1745,7 @@ sub page {  # apply a pager to the output file
 sub searchfor {
     my($self, $recurse,$s,@dirs) = @_;
     $s =~ s!::!/!g;
-    $s = VMS::Filespec::unixify($s) if IS_VMS;
+    $s = VMS::Filespec::unixify($s) if $self->is_vms;
     return $s if -f $s && $self->containspod($s);
     $self->aside( "Looking for $s in @dirs\n" );
     my $ret;
@@ -1749,15 +1755,15 @@ sub searchfor {
     for ($i=0; $i<@dirs; $i++) {
     $dir = $dirs[$i];
     next unless -d $dir;
-    ($dir = VMS::Filespec::unixpath($dir)) =~ s!/\z!! if IS_VMS;
+    ($dir = VMS::Filespec::unixpath($dir)) =~ s!/\z!! if $self->is_vms;
     if (       (! $self->opt_m && ( $ret = $self->check_file($dir,"$s.pod")))
         or ( $ret = $self->check_file($dir,"$s.pm"))
         or ( $ret = $self->check_file($dir,$s))
-        or ( IS_VMS and
+        or ( $self->is_vms and
              $ret = $self->check_file($dir,"$s.com"))
-        or ( IS_OS2 and
+        or ( $self->is_os2 and
              $ret = $self->check_file($dir,"$s.cmd"))
-        or ( (IS_MSWin32 or IS_Dos or IS_OS2) and
+        or ( ($self->is_mswin32 or $self->is_dos or $self->is_os2) and
              $ret = $self->check_file($dir,"$s.bat"))
         or ( $ret = $self->check_file("$dir/pod","$s.pod"))
         or ( $ret = $self->check_file("$dir/pod",$s))
@@ -1778,7 +1784,7 @@ sub searchfor {
         closedir(D)     or $self->die( "Can't closedir $dir: $!" );
         next unless @newdirs;
         # what a wicked map!
-        @newdirs = map((s/\.dir\z//,$_)[1],@newdirs) if IS_VMS;
+        @newdirs = map((s/\.dir\z//,$_)[1],@newdirs) if $self->is_vms;
         $self->aside( "Also looking in @newdirs\n" );
         push(@dirs,@newdirs);
     }
@@ -1794,7 +1800,7 @@ sub searchfor {
 
     return if $already_asserted;
 
-    eval  q~ END { close(STDOUT) || die "Can't close STDOUT: $!" } ~;
+    eval  q~ END { close(STDOUT) || CORE::die "Can't close STDOUT: $!" } ~;
      # What for? to let the pager know that nothing more will come?
 
     $self->die( $@ ) if $@;
@@ -1807,9 +1813,10 @@ sub searchfor {
 
 sub tweak_found_pathnames {
   my($self, $found) = @_;
-  if (IS_MSWin32) {
+  if ($self->is_mswin32) {
     foreach (@$found) { s,/,\\,g }
   }
+  foreach (@$found) { s,',\\',g } # RT 37347
   return;
 }
 
@@ -1840,8 +1847,8 @@ sub drop_privs_maybe {
     my $self = shift;
 
     # Attempt to drop privs if we should be tainting and aren't
-    if (!(IS_VMS || IS_MSWin32 || IS_Dos
-          || IS_OS2
+    if (!( $self->is_vms || $self->is_mswin32 || $self->is_dos
+          || $self->is_os2
          )
         && ($> == 0 || $< == 0)
         && !$self->am_taint_checking()
